@@ -1,6 +1,7 @@
 import typing
 
 from di.api.providers import DependencyProvider
+from di.concurrency import as_async
 from di.dependant import Dependant
 from di.dependant import Injectable as InjectableBase
 from di.dependant import Marker
@@ -46,11 +47,12 @@ def Depends(
     sync_to_thread: bool = False,
     scope: typing.Optional[Scope] = None,
 ) -> typing.Any:
+    if sync_to_thread:
+        call = as_async(call)
     return DependsMarker(
         call=call,
         use_cache=use_cache,
         wire=wire,
-        sync_to_thread=sync_to_thread,
         scope=scope,
     )
 
@@ -67,7 +69,7 @@ class DependsMarker(Marker, typing.Generic[DependencyType]):
         *,
         use_cache: bool = True,
         wire: bool = True,
-        sync_to_thread: bool = True,
+        sync_to_thread: bool = False,
         scope: typing.Optional[Scope] = None,
     ) -> None:
         super().__init__(
@@ -75,16 +77,24 @@ class DependsMarker(Marker, typing.Generic[DependencyType]):
             scope=scope,
             use_cache=use_cache,
             wire=wire,
-            sync_to_thread=sync_to_thread,
         )
+        self.sync_to_thread = sync_to_thread
 
     def as_dependant(self) -> Dependant[DependencyType]:
+        call: "typing.Optional[DependencyProvider]"
+        if self.sync_to_thread:
+            if not self.call:
+                raise ValueError(
+                    "sync_to_thread can only be used if you explicitly declare the target function"
+                )
+            call = as_async(self.call)
+        else:
+            call = self.call
         return Dependant(
-            call=self.call,
+            call=call,  # type: ignore
             scope=self.scope,
             use_cache=self.use_cache,
             wire=self.wire,
-            sync_to_thread=self.sync_to_thread,
             marker=self,
         )
 
